==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/sector/bg/_0204/GeslachtsaanduidingE.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.NoValue;


/**
 * <p>Java class for Geslachtsaanduiding-e complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Geslachtsaanduiding-e">
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>Geslachtsaanduiding">
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Geslachtsaanduiding-e", propOrder = {
    "value"
})
public class GeslachtsaanduidingE {

    @XmlValue
    protected Geslachtsaanduiding value;
    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;
    @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Boolean exact;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link Geslachtsaanduiding }
     *     
     */
    public Geslachtsaanduiding getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link Geslachtsaanduiding }
     *     
     */
    public void setValue(Geslachtsaanduiding value) {
        this.value = value;
    }

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

    /**
     * Gets the value of the exact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExact() {
        if (exact == null) {
            return true;
        } else {
            return exact;
        }
    }

    /**
     * Sets the value of the exact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExact(Boolean value) {
        this.exact = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/GeslachtsaanduidingE.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.NoValue;


/**
 * <p>Java class for Geslachtsaanduiding-e complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Geslachtsaanduiding-e"&gt;
 *   &lt;simpleContent&gt;
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;Geslachtsaanduiding"&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/simpleContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Geslachtsaanduiding-e", propOrder = {
    "value"
})
public class GeslachtsaanduidingE {

    @XmlValue
    protected Geslachtsaanduiding value;
    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;
    @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Boolean exact;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link Geslachtsaanduiding }
     *     
     */
    public Geslachtsaanduiding getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link Geslachtsaanduiding }
     *     
     */
    public void setValue(Geslachtsaanduiding value) {
        this.value = value;
    }

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

    /**
     * Gets the value of the exact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExact() {
        if (exact == null) {
            return true;
        } else {
            return exact;
        }
    }

    /**
     * Sets the value of the exact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExact(Boolean value) {
        this.exact = value;
    }

}
